@@ -27,7 +27,7 @@ BEGIN {
     require Exporter;
 
     # set the version for version checking
-    our $VERSION = 1.15;
+    our $VERSION = 1.16;
 
     # Inherit from Exporter to export functions and variables
     our @ISA = qw(Exporter);
@@ -36,7 +36,7 @@ BEGIN {
     our @EXPORT = qw();
 
     # Functions and variables which can be optionally exported
-    our @EXPORT_OK = qw(@Levels $Modules);
+    our @EXPORT_OK = qw(@Levels);
 } ## end BEGIN
 
 # This can be optionally exported for whatever
